@@ -24,7 +24,7 @@
 
 #include "calls-origin.h"
 #include "calls-message-source.h"
-#include "util.h"
+#include "calls-util.h"
 
 /**
  * SECTION:calls-origin
@@ -40,7 +40,7 @@ enum {
   SIGNAL_CALL_REMOVED,
   SIGNAL_LAST_SIGNAL,
 };
-static guint signals [SIGNAL_LAST_SIGNAL];
+static guint signals[SIGNAL_LAST_SIGNAL];
 
 static void
 calls_origin_default_init (CallsOriginInterface *iface)
@@ -78,21 +78,34 @@ calls_origin_default_init (CallsOriginInterface *iface)
                          NULL,
                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
 
+  /**
+   * CallsOrigin:emergency-numbers:
+   *
+   * The available emergency numbers.
+   */
+  g_object_interface_install_property (
+    iface,
+    g_param_spec_boxed ("emergency-numbers",
+                        "",
+                        "",
+                        G_TYPE_STRV,
+                        G_PARAM_READABLE));
+
   signals[SIGNAL_CALL_ADDED] =
     g_signal_newv ("call-added",
-		   G_TYPE_FROM_INTERFACE (iface),
-		   G_SIGNAL_RUN_LAST,
-		   NULL, NULL, NULL, NULL,
-		   G_TYPE_NONE,
-		   1, arg_types);
+                   G_TYPE_FROM_INTERFACE (iface),
+                   G_SIGNAL_RUN_LAST,
+                   NULL, NULL, NULL, NULL,
+                   G_TYPE_NONE,
+                   1, arg_types);
 
   signals[SIGNAL_CALL_REMOVED] =
     g_signal_newv ("call-removed",
-		   G_TYPE_FROM_INTERFACE (iface),
-		   G_SIGNAL_RUN_LAST,
-		   NULL, NULL, NULL, NULL,
-		   G_TYPE_NONE,
-		   2, arg_types);
+                   G_TYPE_FROM_INTERFACE (iface),
+                   G_SIGNAL_RUN_LAST,
+                   NULL, NULL, NULL, NULL,
+                   G_TYPE_NONE,
+                   2, arg_types);
 }
 
 #define DEFINE_ORIGIN_GETTER(prop,rettype,errval) \
@@ -107,7 +120,7 @@ calls_origin_default_init (CallsOriginInterface *iface)
  * Returns (transfer full): A string containing the name.  The string must be freed by
  * the caller.
  */
-DEFINE_ORIGIN_GETTER(name, char *, NULL);
+DEFINE_ORIGIN_GETTER (name, char *, NULL);
 
 /**
  * calls_origin_get_id:
@@ -118,7 +131,7 @@ DEFINE_ORIGIN_GETTER(name, char *, NULL);
  * Returns (transfer full): A string containing the id.  The string must be freed by
  * the caller.
  */
-DEFINE_ORIGIN_GETTER(id, char *, NULL);
+DEFINE_ORIGIN_GETTER (id, char *, NULL);
 
 /**
  * calls_origin_get_calls:
@@ -129,7 +142,24 @@ DEFINE_ORIGIN_GETTER(id, char *, NULL);
  * Returns: (transfer container): A newly-allocated GList of objects implementing
  * #CallsCall or NULL if there was an error.
  */
-DEFINE_ORIGIN_GETTER(calls, GList *, NULL);
+DEFINE_ORIGIN_GETTER (calls, GList *, NULL);
+
+/**
+ * calls_origin_get_emergency_numbers:
+ * @self: a #CallsOrigin
+ *
+ * Returns: (transfer full): The supported emergency numbers
+ */
+GStrv
+calls_origin_get_emergency_numbers (CallsOrigin *origin)
+{
+  GStrv numbers;
+
+  g_return_val_if_fail (CALLS_IS_ORIGIN (origin), NULL);
+
+  g_object_get (origin, "emergency-numbers", &numbers, NULL);
+  return numbers;
+}
 
 /**
  * calls_origin_foreach_call:
@@ -140,9 +170,9 @@ DEFINE_ORIGIN_GETTER(calls, GList *, NULL);
  * Iterate over all current calls from this origin
  **/
 void
-calls_origin_foreach_call(CallsOrigin *self,
-                          CallsOriginForeachCallFunc callback,
-                          gpointer param)
+calls_origin_foreach_call (CallsOrigin               *self,
+                           CallsOriginForeachCallFunc callback,
+                           gpointer                   param)
 {
   g_autoptr (GList) calls = NULL;
   GList *node;
@@ -164,8 +194,8 @@ calls_origin_foreach_call(CallsOrigin *self,
  * there is an error, an appropriate #message signal will be emitted.
  */
 void
-calls_origin_dial(CallsOrigin *self,
-                  const char  *number)
+calls_origin_dial (CallsOrigin *self,
+                   const char  *number)
 {
   CallsOriginInterface *iface;
 
@@ -175,7 +205,7 @@ calls_origin_dial(CallsOrigin *self,
   iface = CALLS_ORIGIN_GET_IFACE (self);
   g_return_if_fail (iface->dial != NULL);
 
-  return iface->dial(self, number);
+  return iface->dial (self, number);
 }
 
 /**
