@@ -22,11 +22,9 @@
  *
  */
 
-#ifndef CALLS_ORIGIN_H__
-#define CALLS_ORIGIN_H__
+#pragma once
 
 #include "calls-call.h"
-#include "util.h"
 
 #include <glib-object.h>
 
@@ -35,17 +33,16 @@ G_BEGIN_DECLS
 
 #define CALLS_TYPE_ORIGIN (calls_origin_get_type ())
 
-G_DECLARE_INTERFACE (CallsOrigin, calls_origin, CALLS, ORIGIN, GObject);
+G_DECLARE_INTERFACE (CallsOrigin, calls_origin, CALLS, ORIGIN, GObject)
 
 
-struct _CallsOriginInterface
-{
+struct _CallsOriginInterface {
   GTypeInterface parent_iface;
 
-  void               (*dial)                                (CallsOrigin *self,
-                                                             const char  *number);
-  gboolean           (*supports_protocol)                   (CallsOrigin *self,
-                                                             const char  *protocol);
+  void           (*dial)                                (CallsOrigin *self,
+                                                         const char  *number);
+  gboolean       (*supports_protocol)                   (CallsOrigin *self,
+                                                         const char  *protocol);
 };
 
 typedef void (*CallsOriginForeachCallFunc) (gpointer param, CallsCall* call, CallsOrigin* origin);
@@ -60,6 +57,7 @@ void                   calls_origin_dial                    (CallsOrigin *self,
                                                              const char  *number);
 gboolean               calls_origin_supports_protocol       (CallsOrigin *self,
                                                              const char *protocol);
+GStrv                  calls_origin_get_emergency_numbers   (CallsOrigin *self);
+
 G_END_DECLS
 
-#endif /* CALLS_ORIGIN_H__ */
